@@ -5,7 +5,7 @@ use warnings;
 package Sub::SymMethod;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001';
+our $VERSION   = '0.002';
 
 use Exporter::Shiny our @EXPORT = qw( symmethod );
 use Scalar::Util qw( blessed );
@@ -96,6 +96,11 @@ sub install_dispatcher {
 		Carp::carp("Symmethod $name overriding existing method for class $target");
 	}
 	
+	if ( $name eq 'BUILD' or $name eq 'DEMOLISH' or $name eq 'new' ) {
+		require Carp;
+		Carp::carp("Symmethod $name should probably be a plain method");
+	}
+	
 	my $coderef = $class->build_dispatcher( $target, $name );
 	my $qname   = "$target\::$name";
 	
@@ -113,7 +118,7 @@ sub install_dispatcher {
 sub build_dispatcher {
 	my ( $class, $target, $name ) = ( shift, @_ );
 	
-	my $coderef = sub {
+	return sub {
 		my $specs = $class->get_all_symmethods( $_[0], $name );
 		my @results;
 		SPEC: for my $spec ( @$specs ) {
@@ -193,6 +198,7 @@ sub dispatch {
 	sub clear_cache {
 		my ( $class ) = ( shift );
 		delete $CACHE{$_} for @_;
+		return $class;
 	}
 	
 	sub get_all_symmethods {
@@ -215,6 +221,7 @@ sub dispatch {
 }
 
 sub compile_signature {
+	require Type::Params;
 	my ( $class, $spec ) = ( shift, @_ );
 	
 	my @sig = @{ delete $spec->{signature} };
@@ -222,10 +229,11 @@ sub compile_signature {
 	
 	$opt{subname} ||= sprintf( '%s::%s', $spec->{origin}, $spec->{name} );
 	
-	require Type::Params;
 	$spec->{signature} = $spec->{named}
 		? Type::Params::compile_named_oo( \%opt, @sig )
 		: Type::Params::compile( \%opt, @sig );
+	
+	return $class;
 }
 
 sub _generate_symmethod {
@@ -252,7 +260,7 @@ __END__
 
 =head1 NAME
 
-Sub::SymMethod - methods that act a little like BUILD and DEMOLISH
+Sub::SymMethod - symbiotic methods; methods that act a little like BUILD and DEMOLISH
 
 =head1 SYNOPSIS
 
